==> org-lsst-ccs-subsystem-fcs-main-1.4.1-sources.jar: org/lsst/ccs/subsystems/fcs/drivers/CanOpenCommand.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.drivers;

import org.apache.log4j.Logger;

/**
 * NOT USED IN SINGLE FILTER TEST
 * This class is not used for the moment (februar 2012).
 * @author virieux
 */
public class CanOpenCommand {
    
    String commandWord;
    String nodeID;
    String index;
    String subindex;
    String size;
    //String data;
    private static final Logger log = Logger.getLogger("lsst.ccs.subsystem");
    
    public CanOpenCommand(String command, String nodeID, String index, String subindex, String size) {
        
        this.commandWord = command;
        this.nodeID = nodeID;
        this.index = index;
        this.subindex = subindex;
        this.size = size;
    }
    
    public CanOpenCommand(String command, String nodeID, String index) {
        
        this.commandWord = command;
        this.nodeID = nodeID;
        this.index = index;
        this.subindex = null;
        this.size = null;
    }
    
    public CanOpenCommand(String commandLine) {
        log.debug("can open command =" + commandLine);
        String[] words = commandLine.split(",");
        this.commandWord = words[0];
        log.debug("command word:" + this.commandWord);
        if (words.length > 0 ) this.nodeID = words[1]; 
            else this.nodeID = "0";
        if (words.length > 1 ) this.index = words[2];
        if (words.length > 2 ) this.subindex = words[3];
        if (words.length > 3 ) this.size = words[4];
    }
    
   
    /*build a Can Open Command that can understand the C wrapper.*/
    /*Build a sdo commandWord as a String*/
    private String buildWsdoCommand() {
        StringBuilder sb = new StringBuilder("wsdo");
        String sep = ",";
        sb.append(sep); sb.append(nodeID);
        sb.append(sep); sb.append(index);
        sb.append(sep); sb.append(subindex);
        sb.append(sep); sb.append(size);
        log.debug("Command built = " + sb.toString());
        return sb.toString();
    }
    
}

==> org-lsst-ccs-subsystem-fcs-main-1.4.2-sources.jar: org/lsst/ccs/subsystems/fcs/drivers/CanOpenCommand.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.drivers;

import org.lsst.ccs.utilities.logging.Logger;

/**
 * NOT USED IN SINGLE FILTER TEST
 * This class is not used for the moment (februar 2012).
 * @author virieux
 */
public class CanOpenCommand {
    
    String commandWord;
    String nodeID;
    String index;
    String subindex;
    String size;
    //String data;
    private static final Logger log = Logger.getLogger("org.lsst.ccs.subsystem.fcs");
    
    public CanOpenCommand(String command, String nodeID, String index, String subindex, String size) {
        
        this.commandWord = command;
        this.nodeID = nodeID;
        this.index = index;
        this.subindex = subindex;
        this.size = size;
    }
    
    public CanOpenCommand(String command, String nodeID, String index) {
        
        this.commandWord = command;
        this.nodeID = nodeID;
        this.index = index;
        this.subindex = null;
        this.size = null;
    }
    
    public CanOpenCommand(String commandLine) {
        log.debug("can open command =" + commandLine);
        String[] words = commandLine.split(",");
        this.commandWord = words[0];
        log.debug("command word:" + this.commandWord);
        if (words.length > 0 ) this.nodeID = words[1]; 
            else this.nodeID = "0";
        if (words.length > 1 ) this.index = words[2];
        if (words.length > 2 ) this.subindex = words[3];
        if (words.length > 3 ) this.size = words[4];
    }
    
   
    /*build a Can Open Command that can understand the C wrapper.*/
    /*Build a sdo commandWord as a String*/
    private String buildWsdoCommand() {
        StringBuilder sb = new StringBuilder("wsdo");
        String sep = ",";
        sb.append(sep); sb.append(nodeID);
        sb.append(sep); sb.append(index);
        sb.append(sep); sb.append(subindex);
        sb.append(sep); sb.append(size);
        log.debug("Command built = " + sb.toString());
        return sb.toString();
    }
    
}
